@@ -23,7 +23,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.26';
+$VERSION = '0.27';
 
 bootstrap UUID $VERSION;
 
@@ -38,25 +38,25 @@ UUID - DCE compatible Universally Unique Identifier library for Perl
 
 =head1 SYNOPSIS
 
-    use UUID ':all';
+    use UUID 'uuid';
 
-    generate($uuid);               # generate binary UUID, prefer random
-    generate_random($uuid);        # generate binary UUID, using random
-    generate_time($uuid);          # generate binary UUID, using time
+    $string = uuid();   # generate stringified UUID
 
-    $string = uuid();              # generate stringified UUID
+    UUID::generate($uuid);               # new binary UUID; prefer random
+    UUID::generate_random($uuid);        # new binary UUID; use random
+    UUID::generate_time($uuid);          # new binary UUID; use time
 
-    unparse($uuid, $string);       # change $uuid string
-    unparse_lower($uuid, $string); # change $uuid to lowercase string
-    unparse_upper($uuid, $string); # change $uuid to uppercase string
+    UUID::unparse($uuid, $string);       # stringify $uuid; system casing
+    UUID::unparse_lower($uuid, $string); # force lowercase stringify
+    UUID::unparse_upper($uuid, $string); # force uppercase stringify
 
-    $rc = parse($string, $uuid);   # map string to UUID, return -1 on error
+    $rc = UUID::parse($string, $uuid);   # map string to UUID; -1 on error
 
-    copy($dst, $src);              # copy binary UUID from $src to $dst
-    compare($uuid1, $uuid2);       # compare binary UUIDs
+    UUID::copy($dst, $src);              # copy binary UUID from $src to $dst
+    UUID::compare($uuid1, $uuid2);       # compare binary UUIDs
 
-    clear( $uuid );                # set binary UUID to NULL
-    is_null( $uuid);               # compare binary UUID to NULL
+    UUID::clear( $uuid );                # set binary UUID to NULL
+    UUID::is_null( $uuid );              # compare binary UUID to NULL
     
 
 =head1 DESCRIPTION
@@ -191,8 +191,8 @@ respectively, and their derivatives.
 
 =head1 EXPORTS
 
-All functions may be imported in the usual manner, either individually
-or all at once using the "I<:all>" tag.
+None by default. All functions may be imported in the usual manner,
+either individually or all at once using the "I<:all>" tag.
 
 =head1 TODO
 
@@ -232,6 +232,8 @@ William Faulk
 
 gregor herrmann
 
+Slaven Rezic
+
 =head1 SEE ALSO
 
 B<uuid(3)>, B<uuid_clear(3)>, B<uuid_compare(3)>, B<uuid_copy(3)>,
